@@ -2,17 +2,19 @@
 
 Import the package::
 
-   import fcsreader
+   import readfcs
 
 This is the complete API reference:
 
 .. autosummary::
    :toctree: .
 
+   read
    FCSFile
+   datasets
 """
 
-__version__ = "0.1.0"
+__version__ = "0.1.3"
 
 from . import datasets
-from ._core import FCSFile
+from ._core import FCSFile, read
